@@ -37,6 +37,20 @@ AVAILABLE FEATURES IN THE LIBRARY:
             save_to(file, prefix, func_name, choice) - file saver for code clarity.
 
             file_handler(file) - handles the file extension upon import.
+            
+            paint_text(text, color, print_trigger = True) - paints the text with a desired color ('r', 'g', 'b', 'k', 'c', 'm', 'y').
+
+    EXAMPLE (MODULE FUNCTIONS)
+        --------------------------
+
+        set of example functions to perform machine learning and data science operations over.
+            print(help(any_function_listed_below)) in order to see the function details or print(help(vandal.example)) for all functions at once.
+
+        FUNCTIONS (ACCESSIBLE DIRECTLY FROM THE LIBRARY)
+        ------------------------------------------------
+
+            linear_regression(x_range = (1, 500), y_factor = 2, deviation = 50, min_value = 1) -> ReturnType: - creates an example linear regression data set where x is index 0 and y is index 1.
+
 
     MONTECARLO (OBJECT)
     -------------------
@@ -74,6 +88,14 @@ AVAILABLE FEATURES IN THE LIBRARY:
 import sys
 sys.dont_write_bytecode = True
 
+# colorama imports.
+from colorama import (
+    Fore,
+    init,
+)
+
+init()
+
 # meta data imports from the vandal library.
 from vandal.misc._meta import (
     __author__,
@@ -93,33 +115,6 @@ from logistics.plugins.metaclass import Meta
 # imports all data types.
 from logistics.plugins.types import *
 
-# available types.
-types = [
-    VandalType,
-    IntegerType,
-    FloatType,
-    NumberType,
-    ReturnType,
-    PrintType,
-    GraphType,
-    StringType,
-    ListType,
-    TupleType,
-    DictionaryType,
-    BooleanType,
-    FilePathType,
-    SpecialType,
-    NumberVector,
-    StringVector,
-    StringDictionary,
-    DictionaryVector,
-    NumberVectorAlike,
-    NumberArrayAlike,
-    AnyArrayAlike,
-    AnyVectorAlike,
-    AnyType,
-]
-
 # metaclass.
 metaclass = [
     'Meta',
@@ -127,6 +122,7 @@ metaclass = [
 
 # object and module imports.
 from vandal.hub import toolkit
+from vandal.hub import example
 from vandal.objects.eoq import(
     EOQ,
     EOQapp,
@@ -137,7 +133,7 @@ from vandal.objects.montecarlo import (
 )
 from vandal.objects.dijkstra import Dijkstra
 
-# hub imports.
+# hub toolkit imports.
 from vandal.hub.toolkit import (
     random_value,
     random_pool,
@@ -150,10 +146,11 @@ from vandal.hub.toolkit import (
     create_password,
     file_handler,
     save_to,
+    paint_text,
 )
 
-# colorama imports.
-from colorama import Fore, init
+# hub example imports.
+from vandal.hub.example import linear_regression
 
 # all relevant contents.
 __all__ = [
@@ -168,11 +165,15 @@ __all__ = [
     'create_password',
     'file_handler',
     'save_to',
+    'paint_text',
     'toolkit',
+    'example',
+    'linear_regression',
     'MonteCarlo',
     'MCapp',
     'EOQ',
     'EOQapp',
     'Dijkstra',
+    'VandalTypes',
     'Meta',
 ]
