@@ -1,5 +1,7 @@
 # import all relevant contents from the associated module.
 from vandal.hub import toolkit
+from vandal.hub import example
+
 from vandal.hub.toolkit import (
     random_value,
     random_pool,
@@ -12,8 +14,11 @@ from vandal.hub.toolkit import (
     create_password,
     file_handler,
     save_to,
+    paint_text,
 )
 
+from vandal.hub.example import linear_regression
+
 # all relevant contents.
 __all__ = [
     'random_value',
@@ -27,5 +32,8 @@ __all__ = [
     'create_password',
     'file_handler',
     'save_to',
+    'paint_text',
     'toolkit',
+    'example',
+    'linear_regression',
 ]
