@@ -1,8 +1,17 @@
 # coloring.
-from colorama import Fore, init
+from colorama import (
+        Fore,
+        init,
+)
 
 init()
 
+# dependencies.
+import pandas as pd
+import os
+import random
+from logistics.plugins.types import *
+
 '''
 
 (MODULE FUNCTIONS)
@@ -31,6 +40,8 @@ vandal.toolkit is a set of data manipulation tools that can be directly accessed
         save_to(file, prefix, func_name, choice) - file saver for code clarity.
 
         file_handler(file) - handles the file extenstion upon import.
+        
+        paint_text(text, color, print_trigger = True) - paints the text with a desired color ('r', 'g', 'b', 'k', 'c', 'm', 'y').
 	
 '''
 
@@ -48,7 +59,6 @@ from vandal.misc._meta import (
 
 # gives a random value of mean and standard deviation inputed, if rounded = 'y', value will be rounded.
 def random_value(mean, st_dev, **rounded):
-        import random
         if rounded.get('rounded') == 'y':
                 random_value = round(random.gauss(mean, st_dev))
         else:
@@ -58,7 +68,6 @@ def random_value(mean, st_dev, **rounded):
 
 # gives random values of mean and standard deviation inputed for the amount of values defined in the pool size, if rounded = 'y', values will be rounded.
 def random_pool(mean, st_dev, pool_size, **rounded):
-        import random
         if rounded.get('rounded') == 'y':
                 random_pool = [round(random.gauss(mean, st_dev)) for y in range(pool_size)]
         else:
@@ -132,14 +141,11 @@ def auto_sort(data, split_method, trigger = lambda x: x[0]):
 
 # creates a random password with adjustable lenght (default: length = 8).
 def create_password(length = 8):
-        import random
         particles = 'abcdefghijklmnoprstuxwyzqABCDEFGHIJKLMNOPRSTUXWYZQ0123456789'
-
         return ''.join(random.sample(particles, length))
 
 # handles the file extenstion upon import.
 def file_handler(file):
-        import pandas as pd
         file = file.replace("'", '"').strip('"')
         if str(file).endswith('.csv'):
             data = pd.read_csv(file)
@@ -167,8 +173,6 @@ def file_handler(file):
 
 # file saver for code clarity.
 def save_to(file, prefix, func_name, choice):
-        import pandas as pd
-        import os
         if choice == '0' or choice == 'csv':
                 extension = '.csv'
                 file.to_csv(prefix + func_name + extension)
@@ -182,4 +186,21 @@ def save_to(file, prefix, func_name, choice):
                 file.to_json(prefix + func_name + extension)
                 print(Fore.YELLOW + os.path.join(os.getcwd() + '\\' + prefix + func_name + extension) + Fore.RESET)
         else:
-                print('=== NO OPTION CHOSEN, EXITING THE MENU... =\n')
+                print('=== NO OPTION CHOSEN, EXITING THE MENU... ===\n')
+
+#p aints the text with a desired color ('r', 'g', 'b', 'k', 'c', 'm', 'y').
+def paint_text(text, color, print_trigger = True):
+    colors = {'r': Fore.RED,
+              'g' : Fore.GREEN,
+              'b' : Fore.BLUE,
+              'k' : Fore.BLACK,
+              'm' : Fore.MAGENTA,
+              'y' : Fore.YELLOW,
+              'c' : Fore.CYAN,
+              }
+    
+    if print_trigger == True:
+        return print(colors[color] + text + Fore.RESET)
+    
+    elif print_trigger == False:
+        return colors[color] + text + Fore.RESET
\ No newline at end of file
